#!/bin/bash

tmp_cache="tmp-cache"

echo ""

if [ "x$GSDL3SRCHOME" = "x" ] ; then
   echo "Environment variable GSDL3SRCHOME not set." 1>&2
   echo "Have you sourced ./gs3-setup.sh?" 1>&2
   exit 1
fi
   
if [ ! -d $tmp_cache ] ; then
    echo "Making temporary directory:"
    echo "  $tmp_cache"
    mkdir $tmp_cache
else
    echo "Removing existing content from:"
    echo "  $tmp_cache"
    /bin/rm -rf $tmp_cache/*
fi

echo "Copying to '$tmp_cache' then exploding:"

#for f in \
#    "local--countries-in-esc-by-year-in-1956--with-errata.json" \
#    "local--countries-in-esc-by-year-after-1956--with-errata.json" \
#    ; do

    f="local--countries-in-esc-by-year-in-1956--with-errata.json"
    echo "  errata-lod/$f -> $tmp_cache/sparqlresults-$f"    
    /bin/cp "errata-lod/$f" "$tmp_cache/sparqlresults-$f"

    explode_metadata_database.pl \
      -collectdir $GSDL3SRCHOME/web/sites/eurovision-lod/collect \
      -collection eurovision-freshtest \
      -plugin_options "-metadata_merge_on_concat_fields Country,Year,TitleDisambiguation -OIDtype assigned -OIDmetadata Identifier" \
      -plugin JSONSPARQLResultPlugin  \
      $tmp_cache/sparqlresults-$f

    if [ $? != 0 ] ; then
	echo "Error encountered when exploding:" 1>&2
	echo "  $tmp_cache/sparqlresults-$f" 1>&2
	exit 1
    fi


    f="local--countries-in-esc-by-year-after-1956--with-errata.json"
    echo "  errata-lod/$f -> $tmp_cache/sparqlresults-$f"    
    /bin/cp "errata-lod/$f" "$tmp_cache/sparqlresults-$f"

    explode_metadata_database.pl \
      -collectdir $GSDL3SRCHOME/web/sites/eurovision-lod/collect \
      -collection eurovision-freshtest \
      -plugin_options "-metadata_merge_on_concat_fields Country,Year -OIDtype assigned -OIDmetadata Identifier" \
      -plugin JSONSPARQLResultPlugin  \
      $tmp_cache/sparqlresults-$f

    if [ $? != 0 ] ; then
	echo "Error encountered when exploding:" 1>&2
	echo "  $tmp_cache/sparqlresults-$f" 1>&2
	exit 1
    fi    
#done

echo ""
echo "Regenerating sparqlresults-* files in '../import' (from exploded results in '$tmp_cache')"

/bin/rm -rf ../import/sparqlresults-*
/bin/mv $tmp_cache/sparqlresults-* ../import/.

echo ""
